0.9.9 API documentation: vector_float1_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
vector_float1_precision.hpp File Reference

GLM_EXT_vector_float1_precision More...

Go to the source code of this file.

## Typedefs
typedef vec< 1, float, highp > | highp_vec1
| 1 component vector of single-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef vec< 1, float, lowp > | lowp_vec1
| 1 component vector of single-precision floating-point numbers using low precision arithmetic in term of ULPs.
typedef vec< 1, float, mediump > | mediump_vec1
| 1 component vector of single-precision floating-point numbers using medium precision arithmetic in term of ULPs.

## Detailed Description

GLM_EXT_vector_float1_precision

Definition in file vector_float1_precision.hpp.